==> module_qc_tools-2.4.1-py3-none-any.whl: module_qc_tools/cli/IV_MEASURE.py <==
import logging
from datetime import datetime
from pathlib import Path
from tempfile import TemporaryDirectory
from typing import Optional

import typer
from module_qc_data_tools import (
    get_layer_from_sn,
    get_sn_from_connectivity,
    outputDataFrame,
    save_dict_list,
)
from module_qc_database_tools.utils import (
    get_chip_type_from_serial_number,
)

from module_qc_tools.cli.globals import (
    CONTEXT_SETTINGS,
    OPTIONS,
    LogLevel,
)
from module_qc_tools.console import console
from module_qc_tools.measurements.iv_measure import run
from module_qc_tools.utils.misc import (
    add_identifiers_metadata,
    copytree,
    load_hw_config,
    load_meas_config,
)
from module_qc_tools.utils.power_supply import power_supply

logger = logging.getLogger("measurement")

app = typer.Typer(context_settings=CONTEXT_SETTINGS)

# Taking the test-type from the script name which is the test-code in ProdDB.
TEST_TYPE = Path(__file__).stem


@app.command()
def main(
    hw_config_path: Path = OPTIONS["config_hw"],
    meas_config_path: Path = OPTIONS["config_meas"],
    base_output_dir: Path = OPTIONS["output_dir"],
    module_connectivity: Optional[Path] = OPTIONS["module_connectivity"],
    _verbosity: LogLevel = OPTIONS["verbosity"],
    institution: str = OPTIONS["site"],
    use_calib_adc: bool = OPTIONS["use_calib_ADC"],
    save_local: bool = OPTIONS["save_local"],
    vdepl: float = OPTIONS["depl_volt"],
):
    timestart = datetime.now().strftime("%Y-%m-%d_%H%M%S")

    if use_calib_adc:
        logger.warning(
            "The --use-calib-adc was supplied but IV Measure does not use the multimeter, nor the ADC calibration. The flag will be ignored."
        )

    # if -o option used, overwrite the default output directory
    output_dir = module_connectivity.parent if module_connectivity else base_output_dir

    if base_output_dir != Path("outputs"):
        output_dir = base_output_dir

    output_dir = output_dir.joinpath("Measurements", TEST_TYPE, timestart)
    # Make output directory and start log file
    output_dir.mkdir(parents=True, exist_ok=True)

    logger.info(f"Start {TEST_TYPE.replace('_',' ')}!")
    logger.info(f"TimeStart: {timestart}")

    logger.addHandler(logging.FileHandler(output_dir.joinpath("output.log")))

    config_hw = load_hw_config(hw_config_path)

    if module_connectivity:
        config_hw["yarr"]["connectivity"] = module_connectivity

    # Taking the module SN from YARR path to config in the connectivity file.
    module_serial = get_sn_from_connectivity(config_hw["yarr"]["connectivity"])
    layer = get_layer_from_sn(module_serial)
    chip_type = get_chip_type_from_serial_number(module_serial)

    # Load the  measurement config and combine it with the hardware config
    config = load_meas_config(
        meas_config_path, test_type=TEST_TYPE, chip_type=chip_type
    )
    config.update(config_hw)

    # initialize hardware
    ps = power_supply(config["power_supply"])
    hv = power_supply(config["high_voltage"], name="high_voltage", is_hv=True)

    if hv.getPolarity() < 0:
        logger.info(
            f"HV polarity is {hv.getPolarity()} which is opposite to default (1)."
        )
        config["tasks"][TEST_TYPE]["v_max"] = {
            x: abs(y) for x, y in config["v_max"].items()
        }

    try:
        data = run(config, ps, hv, layer)
    except KeyboardInterrupt:
        logger.info("KeyboardInterrupt")
    except Exception as err:
        logger.exception(err)
        raise typer.Exit(1) from err

    add_identifiers_metadata(data, module_serial, institution)
    data.add_meta_data("DepletionVoltage", vdepl)

    alloutput = []

    console.print(data)
    outputDF = outputDataFrame()
    outputDF._serialNumber = module_serial
    outputDF.set_test_type(TEST_TYPE)
    outputDF.set_results(data)
    alloutput += [outputDF.to_dict()]

    with TemporaryDirectory() as tmpdirname:
        save_dict_list(
            Path(tmpdirname).joinpath(f"{module_serial}.json"),
            alloutput,
        )

        # for now, set to false until localDB upload functionality implemented
        upload_failed = True
        upload_implemented = False

        if not save_local:
            # add in logic here to upload to localDB
            msg = "Not implemented yet"
            raise RuntimeError(msg)

        if upload_failed or save_local:
            copytree(tmpdirname, output_dir)
            if upload_failed and upload_implemented:
                logger.warning(
                    "The upload to localDB failed. Please fix and retry uploading the measurement output again."
                )

            logger.info(f"Writing output measurements in {output_dir}")

    logger.info("Done!")
    logger.info(f"TimeEnd: {datetime.now().strftime('%Y-%m-%d_%H%M%S')}")


if __name__ == "__main__":
    typer.run(main)

==> module_qc_tools-2.4.2rc1-py3-none-any.whl: module_qc_tools/cli/IV_MEASURE.py <==
import logging
from datetime import datetime
from pathlib import Path
from tempfile import TemporaryDirectory

import typer
from module_qc_data_tools.qcDataFrame import (
    outputDataFrame,
)
from module_qc_data_tools.utils import (
    get_chip_type_from_serial_number,
    get_layer_from_sn,
    get_sn_from_connectivity,
    save_dict_list,
)

from module_qc_tools.cli.globals import (
    CONTEXT_SETTINGS,
    LogLevel,
    OPTION_config_hw,
    OPTION_config_meas,
    OPTION_depl_volt,
    OPTION_module_connectivity,
    OPTION_output_dir,
    OPTION_save_local,
    OPTION_site,
    OPTION_use_calib_ADC,
    OPTION_verbosity,
    check_module_connectivity,
)
from module_qc_tools.console import console
from module_qc_tools.measurements.iv_measure import run
from module_qc_tools.utils import datapath as mqt_data
from module_qc_tools.utils.misc import (
    add_identifiers_metadata,
    copytree,
    load_hw_config,
    load_meas_config,
)
from module_qc_tools.utils.power_supply import power_supply

logger = logging.getLogger("measurement")

app = typer.Typer(context_settings=CONTEXT_SETTINGS)

# Taking the test-type from the script name which is the test-code in ProdDB.
TEST_TYPE = Path(__file__).stem


@app.command()
def main(
    hw_config_path: OPTION_config_hw = ...,
    meas_config_path: OPTION_config_meas = mqt_data / "configs" / "meas_config.json",
    base_output_dir: OPTION_output_dir = Path("outputs"),
    module_connectivity: OPTION_module_connectivity = None,
    _verbosity: OPTION_verbosity = LogLevel.info,
    institution: OPTION_site = "",
    use_calib_adc: OPTION_use_calib_ADC = False,
    save_local: OPTION_save_local = True,
    vdepl: OPTION_depl_volt = None,
):
    """Run the IV measurement."""
    check_module_connectivity(
        hw_config_path=hw_config_path, module_connectivity=module_connectivity
    )

    timestart = datetime.now().strftime("%Y-%m-%d_%H%M%S")

    if use_calib_adc:
        logger.warning(
            "The --use-calib-adc was supplied but IV Measure does not use the multimeter, nor the ADC calibration. The flag will be ignored."
        )

    # if -o option used, overwrite the default output directory
    output_dir = module_connectivity.parent if module_connectivity else base_output_dir

    if base_output_dir != Path("outputs"):
        output_dir = base_output_dir

    output_dir = output_dir.joinpath("Measurements", TEST_TYPE, timestart)
    # Make output directory and start log file
    output_dir.mkdir(parents=True, exist_ok=True)

    logger.info(f"Start {TEST_TYPE.replace('_',' ')}!")
    logger.info(f"TimeStart: {timestart}")

    logger.addHandler(logging.FileHandler(output_dir.joinpath("output.log")))

    config_hw = load_hw_config(hw_config_path)

    if module_connectivity:
        config_hw["yarr"]["connectivity"] = module_connectivity

    # Taking the module SN from YARR path to config in the connectivity file.
    module_serial = get_sn_from_connectivity(config_hw["yarr"]["connectivity"])
    layer = get_layer_from_sn(module_serial)
    chip_type = get_chip_type_from_serial_number(module_serial)

    # Load the  measurement config and combine it with the hardware config
    config = load_meas_config(
        meas_config_path, test_type=TEST_TYPE, chip_type=chip_type
    )
    config.update(config_hw)

    # initialize hardware
    ps = power_supply(config["power_supply"])
    hv = power_supply(config["high_voltage"], name="high_voltage", is_hv=True)

    if hv.getPolarity() < 0:
        logger.info(
            f"HV polarity is {hv.getPolarity()} which is opposite to default (1)."
        )
        config["tasks"][TEST_TYPE]["v_max"] = {
            x: abs(y) for x, y in config["v_max"].items()
        }

    try:
        data = run(config, ps, hv, layer)
    except KeyboardInterrupt:
        logger.info("KeyboardInterrupt")
    except Exception as err:
        logger.exception(err)
        raise typer.Exit(1) from err

    add_identifiers_metadata(data, module_serial, institution)
    data.add_meta_data("DepletionVoltage", vdepl)

    alloutput = []

    console.print(data)
    outputDF = outputDataFrame()
    outputDF._serialNumber = module_serial
    outputDF.set_test_type(TEST_TYPE)
    outputDF.set_results(data)
    alloutput += [outputDF.to_dict()]

    with TemporaryDirectory() as tmpdirname:
        save_dict_list(
            Path(tmpdirname).joinpath(f"{module_serial}.json"),
            alloutput,
        )

        # for now, set to false until localDB upload functionality implemented
        upload_failed = True
        upload_implemented = False

        if not save_local:
            # add in logic here to upload to localDB
            msg = "Not implemented yet"
            raise RuntimeError(msg)

        if upload_failed or save_local:
            copytree(tmpdirname, output_dir)
            if upload_failed and upload_implemented:
                logger.warning(
                    "The upload to localDB failed. Please fix and retry uploading the measurement output again."
                )

            logger.info(f"Writing output measurements in {output_dir}")

    logger.info("Done!")
    logger.info(f"TimeEnd: {datetime.now().strftime('%Y-%m-%d_%H%M%S')}")


if __name__ == "__main__":
    typer.run(main)
